@@ -38,12 +38,12 @@ class CustomGS extends CMSModule
 	
 	function GetVersion()
 	{
-		return '1.6';
+		return '3.1';
 	}
 	
 	function MinimumCMSVersion()
 	{
-		return '1.10';
+		return '1.12';
 	}
 	
 	function GetHelp()
@@ -53,12 +53,12 @@ class CustomGS extends CMSModule
 	
 	function GetAuthor()
 	{
-		return 'Rolf Tjassens';
+		return 'Rolf Tjassens, Jos';
 	}
 	
 	function GetAuthorEmail()
 	{
-		return 'rolf at cmsmadesimple dot org';
+		return 'info at cmscanbesimple dot org, josvd at live dot nl';
 	}
 	
 	function GetChangeLog()
@@ -88,7 +88,7 @@ class CustomGS extends CMSModule
 
 	function VisibleToAdminUser() 
 	{
-		return ($this->CheckPermission('Custom Global Settings - Manage') || $this->CheckPermission('Custom Global Settings - Use'));
+		return $this->CheckPermission('Custom Global Settings - Manage') || $this->CheckPermission('Custom Global Settings - Use');
 	}
 
 	function GetDependencies()
@@ -96,23 +96,37 @@ class CustomGS extends CMSModule
 		return array();
 	}
 	
-	function SetParameters()
-	{
+	function InitializeFrontend() {
 		$this->RegisterModulePlugin();
 		$this->RestrictUnknownParams();
-		$this->CreateParameter('showvars',1,'Set this parameter to show all available variables and their values. For testing purposes only.');
 		$this->SetParameterType('showvars',CLEAN_INT);
+		
+		$fields = $this->GetSettings();
+		global $CMS_VERSION;
+		if ($CMS_VERSION >= '2') {
+			// by exception we use assignGlobal in stead of assign to make the variable global by default. Not to use in other modules!
+			cmsms()->GetSmarty()->assignGlobal('CustomGS', $fields);
+		}
+		else
+		{
+			cmsms()->GetSmarty()->assign('CustomGS', $fields);
+		}
 	}
 	
-  function GetEventDescription($eventname)
-  {
-    return $this->Lang('event_info_'.$eventname );
-  }
+	function SetParameters()
+	{
+		$this->CreateParameter('showvars',1,'Set this parameter to show all available variables and their values. For testing purposes only.');
+	}
+	
+	function GetEventDescription($eventname)
+	{
+		return $this->Lang('event_info_'.$eventname );
+	}
 
-  function GetEventHelp($eventname)
-  {
-    return $this->Lang('event_help_'.$eventname );
-  }
+	function GetEventHelp($eventname)
+	{
+		return $this->Lang('event_help_'.$eventname );
+	}
 
 	function InstallPostMessage()
 	{
@@ -146,6 +160,12 @@ class CustomGS extends CMSModule
 	.ui-timepicker-div td { font-size: 90%; }
 	.ui-tpicker-grid-label { background: none; border: none; margin: 0; padding: 0; }
 
+	.cgs_pageselect {
+		display: inline-block;
+		height:32px;
+		overflow:hidden;
+	}
+				
 	.cgs_fieldset {
 			margin-top:10px;
 			padding-top:0;
@@ -184,7 +204,7 @@ EOT;
 	function GetField($field)
 	{
 		$db = cmsms()->GetDB();
-		$query = "SELECT * FROM ".cms_db_prefix()."module_customgs WHERE fieldid=? OR name=?";
+		$query = "SELECT * FROM ".cms_db_prefix()."module_customgs WHERE fieldid=? OR name=? ORDER BY fieldid DESC";
 		$result = $db->Execute($query, array($field, $field));
 		if( $result && $result->RecordCount() > 0 )
 		{
@@ -204,7 +224,7 @@ EOT;
 	* @access public
 	* @return array()
 	*/
-	function GetFields()
+	function GetFields($tabid)
 	{
 		$userid = get_userid();
 		$userops = cmsms()->GetUserOperations();
@@ -213,8 +233,10 @@ EOT;
 		$fields = array();
 
 		$db = cmsms()->GetDB();
-		$query = "SELECT * FROM ".cms_db_prefix()."module_customgs ORDER BY sortorder ASC";
-		$result = $db->Execute($query);
+		$query = "SELECT f.* FROM ".cms_db_prefix()."module_customgs f
+					JOIN ".cms_db_prefix()."module_customgs_tabfield tf ON f.fieldid = tf.fieldid AND tf.tabid = ?
+					ORDER BY f.sortorder ASC";
+		$result = $db->Execute($query, array($tabid));
 		if ( $result && $result->RecordCount() > 0 )
 		{
 			while ( $row=$result->FetchRow() )
@@ -242,6 +264,84 @@ EOT;
 		return $fields;
 	}
 
+	/**
+	* Method to get parameters of a tab by name or by tabid
+	*
+	* @final
+	* @access public
+	* @return array()
+	*/
+	function GetTab($tab)
+	{
+		$db = cmsms()->GetDB();
+		$query = "SELECT * FROM ".cms_db_prefix()."module_customgs_tab WHERE tabid=? OR name=?";
+		$result = $db->Execute($query, array($tab, $tab));
+		if( $result && $result->RecordCount() > 0 )
+		{
+			$row = $result->FetchRow();
+		}
+		else
+		{
+			$row = FALSE;
+		}
+		return $row;
+	}
+
+	/**
+	* Method to get tabs
+	*
+	* @final
+	* @access public
+	* @return array()
+	*/
+	function GetTabs($field = NULL)
+	{
+		$userid = get_userid();
+		$userops = cmsms()->GetUserOperations();
+		$adminperm = $userops->UserInGroup($userid, 1); // is admin
+		
+		$tabs = array();
+
+		$db = cmsms()->GetDB();
+		if ( empty($field) ) 
+		{
+			$query = "SELECT * FROM ".cms_db_prefix()."module_customgs_tab ORDER BY sortorder ASC";
+			$result = $db->Execute($query);
+		}
+		else
+		{
+			$query = "SELECT t.*, tf.fieldid AS checked FROM ".cms_db_prefix()."module_customgs_tab t
+						LEFT JOIN ".cms_db_prefix()."module_customgs_tabfield tf ON t.tabid = tf.tabid AND tf.fieldid = ?
+						ORDER BY t.sortorder ASC";
+			$result = $db->Execute($query, array($field));
+		}
+		if ( $result && $result->RecordCount() > 0 )
+		{
+			while ( $row=$result->FetchRow() )
+			{
+				// check editor permissions
+				$editperm = FALSE;
+				if ( !$adminperm && !empty($row['editors']) && empty($field) )
+				{
+					$editors = explode(';', $row['editors']);
+					foreach ($editors as $editor)
+					{
+						$editperm = $editperm || $userops->UserInGroup($userid, $editor);
+					}
+				}
+				else
+				{
+					$editperm = TRUE;
+				}
+				if ( $editperm )
+				{
+					$tabs[] = $row;
+				}
+			}
+		}
+		return $tabs;
+	}
+
 	/**
 	* Method to get all settings
 	*
@@ -270,15 +370,7 @@ EOT;
 					}
 					elseif ( $parseSmarty && ($row['type'] == 'textarea' || $row['type'] == 'wysiwyg') && $row['properties'] )
 					{
-						global $CMS_VERSION;
-						if ( $CMS_VERSION >= '1.11' )
-						{
-							$fields[$alias] = $smarty->fetch('string:'.$row['value']);
-						}
-						else
-						{
-							$fields[$alias] = $this->ProcessTemplateFromData($row['value']);
-						}
+						$fields[$alias] = $smarty->fetch('string:'.$row['value']);
 					}
 					else
 					{
@@ -300,7 +392,7 @@ EOT;
 	*/
 	function ClearStylesheetCache()
 	{
-		foreach (glob("../../tmp/cache/stylesheet_combined_*.css") as $filename) {
+		foreach (glob("../tmp/cache/stylesheet_combined_*.css") as $filename) {
 			@unlink($filename);
 		}
 	}
