@@ -24,18 +24,19 @@
 
 if (!isset($gCms)) exit;
 
-
-$fields = $this->GetSettings();
-
 // Pass the fields to the templates
 if ( isset($params['showvars']) )
 {
+	$fields = $this->GetSettings();
 	foreach ( $fields as $key=>$value )
 	{
 		if ( !is_numeric($key) ) echo '{$CustomGS.' . $key . '} = ' . $value . '<br />';
 	}
 }
-
-$smarty->assign('CustomGS', $fields);
+else 
+{
+	// Redundant {CustomGS} tag found
+	debug_to_log('Redundant {CustomGS} tag found. Since release 2.2 this tag is no longer needed. The module gets automatically initialized. You can remove the tag from your template(s).');
+}
 
 ?>
\ No newline at end of file
