@@ -26,30 +26,34 @@ if (!isset($gCms)) exit;
 
 if( !$this->CheckPermission('Custom Global Settings - Use') ) $this->Redirect($id, "defaultadmin", $returnid);
 
+$tabid = $params['tabid'];
 // Get the fields the user is allowed to edit.
-$fields = $this->GetFields();
+$fields = $this->GetFields($tabid);
 $clearcache = 0;
 
-foreach( $fields as $key => $fieldprops )
+foreach( $fields as $key => $fld )
 {
-	$value = $fieldprops['value'];
-	$newvalue = isset($params['field'][$key]) ? $params['field'][$key] : 0;
+	$value = $fld['value'];
+	$newvalue = isset($params['field'][$tabid][$key]) ? $params['field'][$tabid][$key] : 0;
 		
 	// Sent event only when value has changed.
 	if ( $newvalue != $value )
 	{
-		// Save field value
-		$query = "UPDATE " . cms_db_prefix() . "module_customgs SET value=? WHERE fieldid=?";
-		$result = $db->Execute($query, array($newvalue, $key));
+		if ( $fld['type'] != 'button' )
+		{
+			// Save field value
+			$query = "UPDATE " . cms_db_prefix() . "module_customgs SET value=? WHERE fieldid=?";
+			$result = $db->Execute($query, array($newvalue, $key));
+		}
 
 		$this->SendEvent('OnSettingChange', array(
-					'fieldid' => $fieldprops['fieldid'],
-					'name' => $fieldprops['name'],
-					'alias' => str_replace('__', '_', str_replace('-', '_', munge_string_to_url($fieldprops['name']))),
+					'fieldid' => $fld['fieldid'],
+					'name' => $fld['name'],
+					'alias' => str_replace('__', '_', str_replace('-', '_', munge_string_to_url($fld['name']))),
 					'value' => $newvalue,
-					'clearcache' => $fieldprops['clearcache']
+					'clearcache' => $fld['clearcache']
 		));
-		$clearcache = $clearcache || $fieldprops['clearcache'];
+		$clearcache = $clearcache || $fld['clearcache'];
 	}
 }
 
@@ -62,5 +66,5 @@ debug_display($params);
 // Put mention into the admin log
 audit('', 'Custom Global Settings - General tab', 'Saved');
 
-$this->Redirect($id, 'defaultadmin', $returnid, array('module_message' => $this->Lang('settingssaved'), 'active_tab' => 'general'));
+$this->Redirect($id, 'defaultadmin', $returnid, array('module_message' => $this->Lang('settingssaved'), 'active_tab' => 'tab' . $tabid));
 ?>
\ No newline at end of file
