@@ -30,9 +30,11 @@ if( !$this->CheckPermission('Custom Global Settings - Manage') ) $this->Redirect
 if (isset($params['input_custom_modulename'])) $this->SetPreference('input_custom_modulename', $params['input_custom_modulename']);
 if (isset($params['input_admin_section'])) $this->SetPreference('admin_section', $params['input_admin_section']);
 
-// Clear admin menu cache
-foreach (glob("../tmp/cache/themeinfo*.cache") as $filename) {
-	@unlink($filename);
+// Touch menu cache files
+if (version_compare(CMS_VERSION, '1.99-alpha0', '<')) {
+	foreach (glob(cms_join_path(TMP_CACHE_LOCATION, "themeinfo*.cache")) as $filename) { @unlink($filename); } // 1.11
+} else {
+	foreach (glob(cms_join_path(TMP_CACHE_LOCATION, "cache*.cms")) as $filename) { @unlink($filename); } // 2.0
 }
 
 // Show saved parameters in debug mode
@@ -42,4 +44,5 @@ debug_display($params);
 audit('', 'Custom Global Settings - Options tab', 'Saved');
 
 $this->Redirect($id, 'defaultadmin', $returnid, array('module_message' => $this->Lang('settingssaved'), 'active_tab' => 'options'));
+
 ?>
\ No newline at end of file
