@@ -30,19 +30,44 @@ if( !$this->CheckPermission('Custom Global Settings - Manage') )
 	return;
 }
 
+$tabs = $this->GetTabs(-1);
+$tabid = empty($params['tabid']) ? $tabs[0]['tabid'] : $params['tabid'];
 
-$themeObject = cmsms()->variables['admintheme'];
+if ( count($tabs) > 1 )
+{
+	// create tab dropdownfield
+	foreach ( $tabs as $tab ) 
+	{
+		$label = $tab['name'];
+		$tablist[$label] = $tab['tabid'];
+	}
+	$smarty->assign('tabselect', $this->CreateInputDropdown($id, 'tabselect', $tablist, -1, $tabid, 'id="' . $id . 'tabselect"'));
+	$smarty->assign('tabselectjs', '
+		$(\'#' . $id . 'tabselect\').change( function() {
+			location.href = "' . str_replace('&amp;','&',$this->CreateLink($id, 'defaultadmin', $returnid, '', array('active_tab' => 'fielddefs'), '', true))  . '&' . $id . 'tabid="+$(this).val();
+		});
+');
+}
+else
+{
+	$smarty->assign('tabselect', lang('status'));
+	$smarty->assign('tabselectjs', '');
+}
 
 $rowarray = array();
 
 $db = $this->GetDB();
 $query = "SELECT
-						*
+						f.*, tf.tabid AS checked
 					FROM
-						" . cms_db_prefix() . "module_customgs
+						" . cms_db_prefix() . "module_customgs f
+					LEFT JOIN
+						" . cms_db_prefix() . "module_customgs_tabfield tf
+					ON
+						f.fieldid = tf.fieldid AND tf.tabid = ?
 					ORDER BY
-						sortorder ASC";
-$result = $db->GetAll($query);
+						f.sortorder ASC";
+$result = $db->GetAll($query, array($tabid));
 $rowcount = count($result);
 
 if ( $result && $rowcount > 0 )
@@ -61,21 +86,46 @@ if ( $result && $rowcount > 0 )
 		}
 		//$row->help = $def['help'];
 		$row->type = $this->Lang($def['type']);
-		if ( $def['type'] == 'gbfilepicker' )
+		switch ($def['type']) 
 		{
-			if ( $gbfp = cms_utils::get_module('GBFilePicker') )
-			{
-				$row->type = $gbfp->GetFriendlyName();
-			}
-			else
-			{
-				$row->type = 'GBFilePicker (' . lang('notinstalled') . ')';
-			}
+			case 'corefilepicker':
+				if ( $corefp = cms_utils::get_module('FilePicker') )
+				{
+					$row->type = $corefp->GetFriendlyName();
+				}
+				else
+				{
+					$row->type = 'CMSMS FilePicker (' . lang('notinstalled') . ')';
+				}
+				break;
+			
+			case 'gbfilepicker':
+				if ( $gbfp = cms_utils::get_module('GBFilePicker') )
+				{
+					$row->type = $gbfp->GetFriendlyName();
+				}
+				else
+				{
+					$row->type = 'GBFilePicker (' . lang('notinstalled') . ')';
+				}
+				break;
+				
+			case 'jmfilepicker':
+				if ( $jmfp = cms_utils::get_module('JMFilePicker') )
+				{
+					$row->type = $jmfp->GetFriendlyName();
+				}
+				else
+				{
+					$row->type = 'JMFilePicker (' . lang('notinstalled') . ')';
+				}
+				break;
+				
 		}
 		
 		if ( $def['sortorder'] > 1 )
 		{
-			$row->moveup = $this->CreateLink($id, 'editfielddef', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/arrow-u.gif', lang('up'),'','','systemicon'), array('fieldid' => $def['fieldid'], 'mode'=>'moveup'));
+			$row->moveup = $this->CreateLink($id, 'editfielddef', $returnid, $admintheme->DisplayImage('icons/system/arrow-u.gif', lang('up'),'','','systemicon'), array('fieldid' => $def['fieldid'], 'mode'=>'moveup'));
 		}
 		else
 		{
@@ -84,23 +134,31 @@ if ( $result && $rowcount > 0 )
 		
 		if ( $key < $rowcount - 1 && $result[$key+1]['sortorder'] != 1 )
 		{
-			$row->movedown = $this->CreateLink($id, 'editfielddef', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/arrow-d.gif', lang('down'),'','','systemicon'), array('fieldid' => $def['fieldid'], 'mode'=>'movedown'));
+			$row->movedown = $this->CreateLink($id, 'editfielddef', $returnid, $admintheme->DisplayImage('icons/system/arrow-d.gif', lang('down'),'','','systemicon'), array('fieldid' => $def['fieldid'], 'mode'=>'movedown'));
 		}
 		else
 		{
 			$row->movedown = '';
 		}
 		
+		$trueimage = $admintheme->DisplayImage('icons/system/true.gif', lang('active'), '', '', 'systemicon');
+		$falseimage = $admintheme->DisplayImage('icons/system/false.gif', lang('inactive'), '', '', 'systemicon');
+
+		$row->assigntab = '';
 		$row->editlink = '';
 		$row->deletelink = '';
 		if ( $def['type'] != 'fieldsetend' )
 		{
+			$row->assigntab = '<a href="' . 
+					html_entity_decode($this->create_url($id, 'editfielddef', $returnid, 
+					array('mode' => 'assign', 'tabid' => $tabid, 'fieldid' => $def['fieldid']))) . 
+					'&showtemplate=false" class="assigntab">' . ($def['checked'] ? $trueimage : $falseimage) . '</a>';
 			$row->editlink = $this->CreateLink($id, 'editfielddef', $returnid,
-				    $gCms->variables['admintheme']->DisplayImage ('icons/system/edit.gif', lang ('edit'), '', '', 'systemicon'),
+				    $admintheme->DisplayImage('icons/system/edit.gif', lang('edit'), '', '', 'systemicon'),
 				    array ('fieldid' => $def['fieldid'], 'mode'=>'edit'));
 			$row->deletelink = $this->CreateLink($id, 'editfielddef', $returnid,
-					  $gCms->variables['admintheme']->DisplayImage('icons/system/delete.gif', lang ('delete'), '', '', 'systemicon'),
-					  array ('fieldid' => $def['fieldid'], 'mode'=>'delete'), lang ('deleteconfirm',$def['name']));
+					  $admintheme->DisplayImage('icons/system/delete.gif', lang('delete'), '', '', 'systemicon'),
+					  array ('fieldid' => $def['fieldid'], 'mode'=>'delete'), lang('deleteconfirm',$def['name']));
 		}
 
 		array_push ($rowarray, $row);
@@ -112,6 +170,7 @@ if ( $result === FALSE )
 	exit();
 }
 
+
 $smarty->assign('items', $rowarray );
 $smarty->assign('name', lang('name'));
 $smarty->assign('smartyvar', $this->Lang('smartyvar'));
@@ -120,21 +179,26 @@ $smarty->assign('type', lang('type'));
 
 $smarty->assign('newfielddeflink',
 	  $this->CreateLink($id, 'editfielddef', $returnid,
-			     $gCms->variables['admintheme']->DisplayImage('icons/system/newfolder.gif', lang('add'),'','','systemicon'),
+			     $admintheme->DisplayImage('icons/system/newfolder.gif', lang('add'),'','','systemicon'),
 			     array('mode' => 'add'), '', false, false, '').' '.
 
 	  $this->CreateLink($id, 'editfielddef', $returnid,
 			     lang('add'),
 			     array('mode' => 'add')));
 
+$smarty->assign('showontab', $this->Lang('showontab'));
+$smarty->assign('trueimage',$trueimage);
+$smarty->assign('falseimage',$falseimage);
+
 $smarty->assign('formstart', $this->CreateFormStart ($id, 'editfielddef', $returnid, 'post'));
 $smarty->assign('formend',$this->CreateFormEnd());
 
 $smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', lang('submit')));
-$smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang ('cancel')));
+$smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang('cancel')));
 
 $smarty->assign('mod_id', $id);
 $smarty->assign('ajax_url', html_entity_decode($this->create_url($id, 'editfielddef', $returnid, array('mode' => 'sort'))));
+$smarty->assign('refresh_url', html_entity_decode($this->create_url($id, 'defaultadmin', $returnid)));
 
 echo $this->ProcessTemplate('admin_fielddefs.tpl');
 
