@@ -30,7 +30,6 @@ if( !$this->CheckPermission('Custom Global Settings - Manage') )
 	return;
 }
 
-
 $smarty->assign('title_custom_modulename', $this->Lang('title_custom_modulename'));	
 $smarty->assign('help_custom_modulename', $this->Lang('help_custom_modulename'));
 $smarty->assign('input_custom_modulename',$this->CreateInputText($id, 'input_custom_modulename',$this->GetPreference('input_custom_modulename',''),50,255));
@@ -43,7 +42,7 @@ $smarty->assign('input_admin_section', $this->CreateInputDropdown($id, 'input_ad
 							lang('layout') => 'layout',
 							lang('usersgroups') => 'usersgroups',
 							lang('extensions') => 'extensions',
-							lang('siteadmin') => 'siteadmin',
+							lang('admin') => 'admin',
 							lang('myprefs') => 'myprefs'),
 				-1,
 				$this->GetPreference('admin_section', 'extensions')
