@@ -27,7 +27,7 @@ if (!isset($gCms)) exit;
 /** 
  * Uninstall module
  */
-$db = $gCms->GetDb();
+$db = $this->GetDb();
 
 // remove the database tables
 $dict = NewDataDictionary( $db );
